@@ -1097,11 +1097,7 @@ class KameleoonClient:
         :return: None
         """
         data_not_sent = self._data_not_sent(visitor_code)
-        data = []
-        try:
-            data = data_not_sent[visitor_code]
-        except KeyError:
-            self.logger.debug('No visitor code %s', visitor_code)
+        data = data_not_sent.get(visitor_code, [])
 
         options = {
             "path": self._get_experiment_register_url(visitor_code, experiment_id, variation_id, none_variation),
